/**
 * Required External Modules and Interfaces
 */
import express, {Request, Response} from 'express';
import {addHighlightRouter} from './addHighlight/AddHighlight.router';
import logger from '../../middleware/logger';
import {Guid} from 'guid-typescript';

/**
 * Router Definition
 */
export const highlightMarkerRouter = express.Router();

highlightMarkerRouter.use('/addHighlight', addHighlightRouter);

highlightMarkerRouter.get('/', async (req: Request, res: Response) => {
    try {
        res.status(200).send('Pluto Development Twitch Highlight Marker API Endpoint');
    } catch (e) {
        let errorGuid = Guid.create().toString();
        logger.error('Error handling a request: ' + e.message, {reference: errorGuid});
        res.status(500).send({
            'status': 'PROCESSING_ERROR',
            'message': 'Internal Server Error. Try again later.',
            'reference': errorGuid
        });
    }
});
